/** SEON JavaScript SDK - Copyright (c) SEON Technologies Ltd., 2023 (https://seon.io) */
export type ResolvableHost = 'seon.io' | 'seondf.com' | 'deviceinf.com' | 'getdeviceinf.com';
export interface SDKOptions {
    /**
     * Enable/disable audio_fingerprint module. Note: changing this flag will affect the browser_hash.
     * Highly recommended to enable. Enabled by default.
     */
    audio_fingerprint: boolean;
    /**
     * Enable/disable canvas_fingerprint module. Note: changing this flag will affect the
     * browser_hash. Highly recommended to enable. Enabled by default.
     */
    canvas_fingerprint: boolean;
    /** If CNAME cloaking is set up for the SDK, use this field to specify your domain. */
    cname_server: string | undefined;
    /** Timeout for the DNS resolver in milliseconds. Default: 2000 */
    dnsTimeout: number;
    /** Return the list of detected fonts in addition to the font_hash. Default: false */
    font_list: boolean;
    /**
     * Domain where the JavaScript Agent is hosted. If the field is not added or defined, it defaults
     * to seon.io.
     *
     * In case of an ad blocker blocks our script, please use one of our alternative hosts and make
     * sure you use the same domain as host that you used for loading the script.
     */
    host?: ResolvableHost;
    /**
     * Maximum delay for accurate proxy identification. Values greater than 5000 will be clamped to
     * 5000. Default: 0 (no delay is allowed)
     */
    max_proxy_delay: number;
    /** Callback function for error during config setup. */
    onError?: (msg?: string) => void;
    /** Callback function for successful config setup. */
    onSuccess?: (msg?: string) => void;
    /**
     * Session ID is a custom string that you can use to link device data with transactions. It is a
     * custom unique identifier that should be based on your customer current session, for example
     * tracking cookies.
     */
    session_id: string | undefined;
    /** @private */
    similarity_hash: boolean;
    /** @private */
    verbose: boolean;
    /**
     * Enable/disable webgl_fingerprint module. Note: changing this flag will affect the browser_hash.
     * Highly recommended to enable. Enabled by default.
     */
    webgl_fingerprint: boolean;
    /**
     * Geolocation feature config.
     *
     * - None: No geolocation.
     * - Fast: We wait for geolocation up to the DC response. Lower chance to receive a location fix.
     *   Lower accuracy.
     * - Accurate: We wait for geolocation up to the dns timeout. Higher chance to receive a location
     *   fix. Higher accuracy.
     * - Strict: Same as 'accurate'. In the future this will throw an Error when no Geolocation data is
     *   available.
     *
     * Default: 'fast'
     */
    geolocation: 'none' | 'fast' | 'accurate' | 'strict';
    /**
     * The maximum age of geolocation data in seconds.
     *
     * Default: 600 (10 minutes)
     */
    geolocation_age: number;
    /**
     * Whether to enable a possible geolocation permission prompt or not. This is also because some
     * browsers don't user the 'granted' state, only 'prompt' state. So it is only possible to get the
     * geolocation if we use prompt. If geolocation is set to 'strict', then this flag will always be
     * 'true'.
     *
     * Default: false
     */
    geolocation_prompt: boolean;
}
type WithRequired<T, K extends keyof T> = T & {
    [P in K]-?: T[P];
};
/**
 * Configuration parameters for the SDK
 *
 * @see https://docs.seon.io/api-reference#javascript-agent-v5
 */
export type SDKConfigOptions = WithRequired<SDKOptions, 'session_id'>;
/**
 * The setup function for the SDK that takes a configuration object. Only the session_id field is
 * required.
 *
 * @see https://docs.seon.io/api-reference#javascript-agent-v5
 */
declare const config: (options: SDKConfigOptions) => void;
/**
 * This function must be called after the SDK was initialized using the seon.config() function. It
 * returns a Promise with the encrypted payload. Alternatively you can pass a callback function that
 * will be called with the result.
 *
 * @see https://docs.seon.io/api-reference#javascript-agent-v5
 */
declare const getBase64Session: (callback?: (result: string) => void) => Promise<string>;
export { config, getBase64Session };
declare const _default: {
    /**
     * The setup function for the SDK that takes a configuration object. Only the session_id field is
     * required.
     *
     * @see https://docs.seon.io/api-reference#javascript-agent-v5
     */
    config: (options: SDKConfigOptions) => void;
    /**
     * This function must be called after the SDK was initialized using the seon.config() function. It
     * returns a Promise with the encrypted payload. Alternatively you can pass a callback function
     * that will be called with the result.
     *
     * @see https://docs.seon.io/api-reference#javascript-agent-v5
     */
    getBase64Session: (callback?: (result: string) => void) => Promise<string>;
};
export default _default;
